pub struct RunConfig { /* private fields */ }Expand description
Configuration that can be run. This maintains the snapshot of the state of the machine, such as the current instruction pointer, current memory contents, the function stack, etc.
Implementations
Sourceimpl RunConfig
impl RunConfig
Sourcepub fn push_value<F>(&mut self, f: F)where
StackValue: From<F>,
pub fn push_value<F>(&mut self, f: F)where
StackValue: From<F>,
Push a value to the configuration’s stack. This is typically used when the interrupt produced a response.